# HarmBench

This folder includes a copy of the `standard` subset of the [`harmbench_behaviors_text_all.csv`](https://github.com/centerforaisafety/HarmBench/blob/main/data/behavior_datasets/harmbench_behaviors_text_all.csv) dataset from [HarmBench](https://github.com/centerforaisafety/HarmBench/tree/main). The dataset is available under an [MIT License](https://github.com/centerforaisafety/HarmBench/blob/main/LICENSE) in the HarmBench repository.

If using the HarmBench dataset or a probe such as FITD that makes use of it, please consider citing [the HarmBench paper](https://arxiv.org/abs/2402.04249):
```
@article{mazeika2024harmbench,
  title={HarmBench: A Standardized Evaluation Framework for Automated Red Teaming and Robust Refusal},
  author={Mantas Mazeika and Long Phan and Xuwang Yin and Andy Zou and Zifan Wang and Norman Mu and Elham Sakhaee and Nathaniel Li and Steven Basart and Bo Li and David Forsyth and Dan Hendrycks},
  year={2024},
  eprint={2402.04249},
  archivePrefix={arXiv},
  primaryClass={cs.LG}
}
```